==> goreleaser-1.10.3.tar.gz: goreleaser-1.10.3/EULA.md <==
# GoReleaser End User License Agreement (EULA)

## 1. Licensed software.
GoReleaser Pro is licensed as commercial software and must not be used without a valid license key from Becker Software LTDA

### 1.1 "Supplier"

Becker Software LTDA ("Supplier") is a registered company in Joinville, Santa Catarina, Brazil.

## 2. Your agreement.

By accessing, executing, or otherwise using the Licensed Software, you ("Customer") acknowledge that you have read this Agreement, understand it, and agree to be bound by its terms and conditions.
If you are not willing to be bound by the terms of this Agreement, do not access or use the Licensed Software.

### 2.1 Using the Licensed Software in your capacity as an employee.

If you are using the Licensed Software in your capacity as employee or agent of a company or organization, then any references to “you” in this Agreement shall refer to such entity and not to you in your personal capacity.
You warrant that you are authorized to legally bind the company or organization on whose behalf you are accessing the Licensed Software.
If you are not so authorized, then neither you nor your company or organization may use the Licensed Software in any manner whatsoever.

### 2.2 Parts involved.

This Agreement, including any supplemental terms is between You ("Customer") and Becker Software LTDA ("Supplier").

### 2.3 Governing law.
This Agreement is entered into the law of Brazil and shall be governed by, and construed in accordance with, the laws of Brazil, exclusive of its choice of law rules.

## 3. Free Trial

If you either register on the GoReleaser Pro web site for a free trial or otherwise order a free trial version, Becker Software LTDA will make certain Licensed Software available to you on a trial basis (the "Trial Version") free of charge until the end of the free trial period for which you registered or ordered the applicable Licensed Software.
The Trial Version may be used only to review, demonstrate and evaluate the Licensed Software and may have limited features.
The Trial Version may cease operating after the applicable time period or number of uses based on an internal metering mechanism within the Trial Version itself.
Regardless of any such metering, you must stop use at the end of such period or number of uses.
Additional trial terms and conditions may appear on the trial registration web page or Order Form.
Any such additional terms and conditions are incorporated into this Agreement by reference and are legally binding.

## 4. Grant of License; Ownership.

### 4.1 License Grant.
Subject to the terms and conditions of this Agreement and Order Form, Becker Software LTDA hereby:

- (i) grants to the Licensee a limited, non-exclusive, non-transferable, revocable, license to use the Licensed Software and solely for its internal business purposes for use by End Users and for the term and in accordance with the conditions and limitations set forth herein and in the Order Form.
- (ii) To the extent that there is any Third Party Software embedded in, bundled with, or otherwise provided to Licensee in connection with the Licensed Program Materials under this License Agreement, such third party software shall be considered Licensed Software and such Third Party Software shall be used and operated solely with the operation of the Licensed Program Materials and not as a standalone application or any other purpose.
Certain Third Party Software may be subject to an open source license (“OSS License”), which when required by such license is included with the documentation for the Licensed Software (“Documentation”).
Licensee’s license rights with respect to Third Party Software subject to an OSS License are defined by the terms of the applicable OSS License; nothing in this Agreement shall restrict, limit, or otherwise affect any rights or obligations Licensee may have, or conditions to which Licensee may be subject, under such OSS License.
The foregoing includes, without limitation, the MIT License found at: https://opensource.org/licenses/MIT

### 4.2 Ownership.

As between the parties, Becker Software LTDA retains all right, title and interest in the Licensed Program Materials, including but not limited to any and all Intellectual Property Rights in the Licensed Program Materials now owned or that may be owned in the future by Becker Software LTDA

### 4.3 Intellectual Property Rights (IPR).

Copyright for samples, code, logos, trademarks, diagrams and documentation rests with Becker Software LTDA.
All pre-existing IPR remains the property of the originating party; and it is agreed that no IPR is transferred from the Client to the Supplier under this agreement.

### 4.4 Restrictions.

Licensee shall not distribute, display, sublicense, rent, lease, use in a service bureau, modify, translate, reverse engineer, decompile, disassemble, create derivative works based on, or copy the Licensed Program Materials, except to the extent expressly permitted by applicable law, and only to the extent Becker Software LTDA shall not be permitted by that applicable law to exclude or limit such rights.

### 4.5 Feedback.

Customer may provide feedback to Becker Software LTDA about the Products (e.g. technical support input, suggestions, or enhancement requests).
Becker Software LTDA may develop, modify, and improve the Products based on Customer’s Feedback without obligation to Customer, and Customer irrevocably assigns to Becker Software LTDA all right, title, and interest in that Feedback.

## 5. Termination and ongoing effectiveness

This Agreement is effective from the first date you install and/or use the Software.
You may terminate this Agreement at any time by permanently deleting, destroying and returning, at your own cost, the Software, all backup copies and all related materials provided by Becker Software LTDA Becker Software LTDA or its licensors may terminate this Agreement at any time without notice if you fail to comply with any terms or conditions of this Agreement.
Once it is terminated you MUST stop using this Software and delete all the Software and associated materials already copied and/or installed on your computer immediately.

## 6. Customer Data

### 6.1 Customer Data.

In order to use the Products, Customer may need to complete a registration process and provide contact information such as an email address, credentials and other account billing information ("Account Data").
Customer must provide complete and accurate Account Data during the registration process and must keep Customer's Account Data up-to-date.
Customer is prohibited from misrepresenting Customer's identity or affiliation with any company or other entity.
By providing Account Data, Customer hereby consents that it may receive email or other communications from Becker Software LTDA Such communications may include communications regarding Customer's use of the Products and/or commercial content relating to other Becker Software LTDA Products.
If you do not wish to receive such communications, a Customer may opt-out by notifying Becker Software LTDA at carlos@becker.software.

## 7. Co-Marketing

At the request of Supplier, Customer agrees to participate in other reasonable marketing activities that promote the benefits of the Services to other potential customers and to use of Customer's name and logo on the Supplier's web site and in Supplier's promotional materials.
Customer agrees that Supplier may disclose Customer as a customer of the Products.

## 8. Limitation of Liability.

### 8.1 Warranty disclaimer.

You acknowledge that the Software is provided "as is" without warranty of any kind, express or implied.
You use the Software at your own risk and the product is supplied on an "as is" and "as available" basis.
You assume all responsibility for selecting the Software to achieve your intended results, and for the installation of, and results obtained from the Software.

### 8.2 No Consequential Damages.

IN NO EVENT SHALL Becker Software LTDA BE LIABLE HEREUNDER FOR SPECIAL, PUNITIVE, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES, INCLUDING, BUT NOT LIMITED TO, LOSS OF PROFITS, LOSS OF REVENUE, LOSS OF USE OR LOSS OF DATA, EVEN IF ADVISED OF THE POSSIBILITY THEREOF OR, IF REASONABLY FORESEEABLE, INCURRED BY LICENSEE OR END USERS, OR CLAIMED AGAINST LICENSEE BY ANY OTHER PARTY, INCLUDING END USERS (WHETHER ANY SUCH CLAIMS ARISE UNDER THEORY OF CONTRACT, TORT OR OTHERWISE).

### 8.3 Limitation of Liability.

To the extent permitted by applicable law, the liability of Becker Software LTDA and its licensors, personnel, subcontractors and suppliers arising out of, in connection with, or resulting from this Agreement and, without limitation, for any and all causes with respect to the Licensed Program Materials, breach of contract, tort, warranty or otherwise, shall in the aggregate not exceed the license fees paid by Licensee hereunder in the six (6) months immediately preceding the event giving rise to the claim.

### 8.4 After termination.

Sections 1, 2, 3, 4, 5, 6, 7 and 8 will remain effective after the termination of the Agreement.

### 8.5 Question and feedback.

If you have any questions or feedback about these terms or our Services you may contact us by email at: carlos@becker.software.

==> goreleaser-1.23.0.tar.gz: goreleaser-1.23.0/EULA.md <==
# GoReleaser End User License Agreement (EULA)

## 1. Licensed software.
GoReleaser Pro is licensed as commercial software and must not be used without a valid license key from Becker Software LTDA

### 1.1 "Supplier"

Becker Software LTDA ("Supplier") is a registered company in Joinville, Santa Catarina, Brazil.

## 2. Your agreement.

By accessing, executing, or otherwise using the Licensed Software, you ("Customer") acknowledge that you have read this Agreement, understand it, and agree to be bound by its terms and conditions.
If you are not willing to be bound by the terms of this Agreement, do not access or use the Licensed Software.

### 2.1 Using the Licensed Software in your capacity as an employee.

If you are using the Licensed Software in your capacity as employee or agent of a company or organization, then any references to “you” in this Agreement shall refer to such entity and not to you in your personal capacity.
You warrant that you are authorized to legally bind the company or organization on whose behalf you are accessing the Licensed Software.
If you are not so authorized, then neither you nor your company or organization may use the Licensed Software in any manner whatsoever.

### 2.2 Parts involved.

This Agreement, including any supplemental terms is between You ("Customer") and Becker Software LTDA ("Supplier").

### 2.3 Governing law.
This Agreement is entered into the law of Brazil and shall be governed by, and construed in accordance with, the laws of Brazil, exclusive of its choice of law rules.

## 3. Free Trial

If you either register on the GoReleaser Pro web site for a free trial or otherwise order a free trial version, Becker Software LTDA will make certain Licensed Software available to you on a trial basis (the "Trial Version") free of charge until the end of the free trial period for which you registered or ordered the applicable Licensed Software.
The Trial Version may be used only to review, demonstrate and evaluate the Licensed Software and may have limited features.
The Trial Version may cease operating after the applicable time period or number of uses based on an internal metering mechanism within the Trial Version itself.
Regardless of any such metering, you must stop use at the end of such period or number of uses.
Additional trial terms and conditions may appear on the trial registration web page or Order Form.
Any such additional terms and conditions are incorporated into this Agreement by reference and are legally binding.

## 4. Grant of License; Ownership.

### 4.1 License Grant.
Subject to the terms and conditions of this Agreement and Order Form, Becker Software LTDA hereby:

- (i) grants to the Licensee a limited, non-exclusive, non-transferable, revocable, license to use the Licensed Software and solely for its internal business purposes for use by End Users and for the term and in accordance with the conditions and limitations set forth herein and in the Order Form.
- (ii) To the extent that there is any Third Party Software embedded in, bundled with, or otherwise provided to Licensee in connection with the Licensed Program Materials under this License Agreement, such third party software shall be considered Licensed Software and such Third Party Software shall be used and operated solely with the operation of the Licensed Program Materials and not as a standalone application or any other purpose.
Certain Third Party Software may be subject to an open source license (“OSS License”), which when required by such license is included with the documentation for the Licensed Software (“Documentation”).
Licensee’s license rights with respect to Third Party Software subject to an OSS License are defined by the terms of the applicable OSS License; nothing in this Agreement shall restrict, limit, or otherwise affect any rights or obligations Licensee may have, or conditions to which Licensee may be subject, under such OSS License.
The foregoing includes, without limitation, the MIT License found at: https://opensource.org/licenses/MIT

### 4.2 Ownership.

As between the parties, Becker Software LTDA retains all right, title and interest in the Licensed Program Materials, including but not limited to any and all Intellectual Property Rights in the Licensed Program Materials now owned or that may be owned in the future by Becker Software LTDA

### 4.3 Intellectual Property Rights (IPR).

Copyright for samples, code, logos, trademarks, diagrams and documentation rests with Becker Software LTDA.
All pre-existing IPR remains the property of the originating party; and it is agreed that no IPR is transferred from the Client to the Supplier under this agreement.

### 4.4 Restrictions.

Licensee shall not distribute, display, sublicense, rent, lease, use in a service bureau, modify, translate, reverse engineer, decompile, disassemble, create derivative works based on, or copy the Licensed Program Materials, except to the extent expressly permitted by applicable law, and only to the extent Becker Software LTDA shall not be permitted by that applicable law to exclude or limit such rights.

### 4.5 Feedback.

Customer may provide feedback to Becker Software LTDA about the Products (e.g. technical support input, suggestions, or enhancement requests).
Becker Software LTDA may develop, modify, and improve the Products based on Customer’s Feedback without obligation to Customer, and Customer irrevocably assigns to Becker Software LTDA all right, title, and interest in that Feedback.

## 5. Termination and ongoing effectiveness

This Agreement is effective from the first date you install and/or use the Software.
You may terminate this Agreement at any time by permanently deleting, destroying and returning, at your own cost, the Software, all backup copies and all related materials provided by Becker Software LTDA Becker Software LTDA or its licensors may terminate this Agreement at any time without notice if you fail to comply with any terms or conditions of this Agreement.
Once it is terminated you MUST stop using this Software and delete all the Software and associated materials already copied and/or installed on your computer immediately.

## 6. Customer Data

### 6.1 Customer Data.

In order to use the Products, Customer may need to complete a registration process and provide contact information such as an email address, credentials and other account billing information ("Account Data").
Customer must provide complete and accurate Account Data during the registration process and must keep Customer's Account Data up-to-date.
Customer is prohibited from misrepresenting Customer's identity or affiliation with any company or other entity.
By providing Account Data, Customer hereby consents that it may receive email or other communications from Becker Software LTDA Such communications may include communications regarding Customer's use of the Products and/or commercial content relating to other Becker Software LTDA Products.
If you do not wish to receive such communications, a Customer may opt-out by notifying Becker Software LTDA at carlos@becker.software.

## 7. Co-Marketing

At the request of the Supplier and only with prior written approval from the Customer for each use of Customer's name and logo, Customer agrees to participate in other reasonable marketing activities that promote the benefits of the Services to other potential customers and to use of Customer's name and logo on the Supplier's web site and in Supplier's promotional materials.
Customer agrees that Supplier may disclose Customer as a customer of the Products only with Customer's prior written approval for each use.

## 8. Limitation of Liability.

### 8.1 Warranty disclaimer.

You acknowledge that the Software is provided "as is" without warranty of any kind, express or implied.
You use the Software at your own risk and the product is supplied on an "as is" and "as available" basis.
You assume all responsibility for selecting the Software to achieve your intended results, and for the installation of, and results obtained from the Software.

### 8.2 No Consequential Damages.

IN NO EVENT SHALL Becker Software LTDA BE LIABLE HEREUNDER FOR SPECIAL, PUNITIVE, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES, INCLUDING, BUT NOT LIMITED TO, LOSS OF PROFITS, LOSS OF REVENUE, LOSS OF USE OR LOSS OF DATA, EVEN IF ADVISED OF THE POSSIBILITY THEREOF OR, IF REASONABLY FORESEEABLE, INCURRED BY LICENSEE OR END USERS, OR CLAIMED AGAINST LICENSEE BY ANY OTHER PARTY, INCLUDING END USERS (WHETHER ANY SUCH CLAIMS ARISE UNDER THEORY OF CONTRACT, TORT OR OTHERWISE).

### 8.3 Limitation of Liability.

To the extent permitted by applicable law, the liability of Becker Software LTDA and its licensors, personnel, subcontractors and suppliers arising out of, in connection with, or resulting from this Agreement and, without limitation, for any and all causes with respect to the Licensed Program Materials, breach of contract, tort, warranty or otherwise, shall in the aggregate not exceed the license fees paid by Licensee hereunder in the six (6) months immediately preceding the event giving rise to the claim.

### 8.4 After termination.

Sections 1, 2, 3, 4, 5, 6, 7 and 8 will remain effective after the termination of the Agreement.

### 8.5 Question and feedback.

If you have any questions or feedback about these terms or our Services you may contact us by email at: carlos@becker.software.
